@@ -43,21 +43,21 @@ def _get_text_dimensions(text: str) -> Tuple[int, int]:
 
 def _print_ui(screen, filepath: Path) -> None:
 	"""
-	Print the header and footer bars to the screen
+	Print the header and footer bars to the screen.
 	"""
 
-	# Wipe the current screen, in case we resized
+	# Wipe the current screen, in case we resized.
 	screen.clear()
 
 	screen_height, screen_width = screen.getmaxyx()
 
 	header_bar = str(filepath)
 
-	# If the filepath is longer than the screen, use the filename instead
+	# If the filepath is longer than the screen, use the filename instead.
 	if len(str(filepath)) > screen_width:
 		header_bar = str(filepath.name)
 
-	# Fill blank space in the header bar
+	# Fill blank space in the header bar.
 	fill_space = max(floor((screen_width - len(header_bar)) / 2), 0)
 
 	if fill_space:
@@ -66,9 +66,8 @@ def _print_ui(screen, filepath: Path) -> None:
 	if len(header_bar) < screen_width:
 		header_bar = header_bar + " "
 
-	# Create the footer bar
-	# Be very careful with generating a footer of correct width, because unlike
-	# the header, a footer that is too long will cause curses to crash
+	# Create the footer bar.
+	# Be very careful with generating a footer of correct width, because unlike the header, a footer that is too long will cause curses to crash.
 	footer_bar = "(y)es (n)o (a)ccept remaining (r)eject remaining (c)enter on match (q)uit"
 
 	if len(footer_bar) >= screen_width:
@@ -82,11 +81,11 @@ def _print_ui(screen, filepath: Path) -> None:
 	if fill_space:
 		footer_bar = f"{footer_bar}{' ': <{fill_space}}"
 
-	# Print the header and footer
+	# Print the header and footer.
 	screen.attron(curses.A_REVERSE)
 	screen.addstr(0, 0, header_bar)
 
-	# Make accelerators bold
+	# Make accelerators bold.
 	footer_index = 0
 	for char in footer_bar:
 		if char == "(":
@@ -98,7 +97,7 @@ def _print_ui(screen, filepath: Path) -> None:
 
 		screen.addstr(screen_height - 1, footer_index, char)
 		footer_index = footer_index + 1
-	# The bottom right corner has to be set with insch() for some reason
+	# The bottom right corner has to be set with `insch()` for some reason.
 	screen.insch(screen_height - 1, screen_width - 1, " ")
 	screen.attroff(curses.A_REVERSE)
 
@@ -106,13 +105,11 @@ def _print_ui(screen, filepath: Path) -> None:
 
 def _get_center_of_match(text: str, match_start: int, match_end: int, screen_height: int, screen_width: int) -> Tuple[int, int]:
 	"""
-	Given the text, the start and end of the match, and the screen dimensions, return
-	a tuple representing the pad x and y that will result in the pad's
-	view being centered on the match.
+	Given the text, the start and end of the match, and the screen dimensions, return a tuple representing the pad x and y that will result in the pad's view being centered on the match.
 	"""
 
-	# Now we want to try to center the highlighted section on the screen
-	# First, get the row/col dimensions of the highlighted region
+	# Now we want to try to center the highlighted section on the screen.
+	# First, get the row/col dimensions of the highlighted region.
 	index = 0
 	highlight_start_x = 0
 	highlight_start_y = 0
@@ -157,37 +154,35 @@ def _print_screen(screen, filepath: Path, text: str, start_matching_at: int, reg
 	"""
 	Print the complete UI to the screen.
 
-	Returns a tuple of (pad, line_numbers_pad, pad_y, pad_x, match_start, match_end)
-	if there are more replacements to be made. If not, returns a tuple of
-	(None, None, 0, 0, 0, 0)
+	Returns a tuple of (pad, line_numbers_pad, pad_y, pad_x, match_start, match_end) if there are more replacements to be made. If not, returns a tuple of (None, None, 0, 0, 0, 0).
 	"""
 
-	# Get the dimensions of the complete text, and the terminal screen
+	# Get the dimensions of the complete text, and the terminal screen.
 	text_height, text_width = _get_text_dimensions(text)
 	screen_height, screen_width = screen.getmaxyx()
 	line_numbers_height = text_height
 	line_numbers_width = len(str(text_height))
 
-	# Create the line numbers pad
+	# Create the line numbers pad.
 	line_numbers_pad = curses.newpad(line_numbers_height, line_numbers_width)
-	# Reset the cursor
+	# Reset the cursor.
 	line_numbers_pad.addstr(0, 0, "")
 	line_numbers_pad.attron(curses.A_REVERSE)
 	line_numbers_pad.attron(curses.A_DIM)
-	# Add the line numbers
+	# Add the line numbers.
 	for i in range(line_numbers_height - 1):
 		line_numbers_pad.addstr(i, 0, f"{i + 1}".rjust(line_numbers_width))
 
-	# Create a new pad
+	# Create a new pad.
 	pad = curses.newpad(text_height, text_width)
 
 	pad.keypad(True)
 
-	# Reset the cursor
+	# Reset the cursor.
 	pad.addstr(0, 0, "")
 
 	# Do we have a regex match in the text?
-	# We only consider text after the last completed match
+	# We only consider text after the last completed match.
 	match = regex.search(fr"{regex_search}", text[start_matching_at:], flags=regex_flags)
 
 	if not match:
@@ -196,24 +191,24 @@ def _print_screen(screen, filepath: Path, text: str, start_matching_at: int, reg
 	match_start = start_matching_at + match.start()
 	match_end = start_matching_at + match.end()
 
-	# Print the text preceding the match
+	# Print the text preceding the match.
 	pad.addstr(text[:match_start])
-	# Print the match itself, in reversed color
+	# Print the match itself, in reversed color.
 	if curses.has_colors():
 		pad.addstr(text[match_start:match_end], curses.color_pair(1) | curses.A_BOLD)
 	else:
 		pad.attron(curses.A_REVERSE)
 		pad.addstr(text[match_start:match_end])
 		pad.attroff(curses.A_REVERSE)
-	# Print the text after the match
+	# Print the text after the match.
 	pad.addstr(text[match_end:len(text)])
 
 	pad_y, pad_x = _get_center_of_match(text, match_start, match_end, screen_height, screen_width)
 
-	# Print the header and footer
+	# Print the header and footer.
 	_print_ui(screen, filepath)
 
-	# Output to the screen
+	# Output to the screen.
 	pad.refresh(pad_y, pad_x, 1, line_numbers_width, screen_height - 2, screen_width - 1)
 
 	line_numbers_pad.refresh(pad_y, 0, 1, 0, screen_height - 2, line_numbers_width)
@@ -221,9 +216,9 @@ def _print_screen(screen, filepath: Path, text: str, start_matching_at: int, reg
 	return (pad, line_numbers_pad, pad_y, pad_x, match_start, match_end)
 
 def _init_screen(screen):
-	# Initialize curses
+	# Initialize curses.
 
-	# Only initialize the screen if it's not already initialized
+	# Only initialize the screen if it's not already initialized.
 	if screen is not None:
 		return screen
 
@@ -232,11 +227,10 @@ def _init_screen(screen):
 	if curses.has_colors():
 		curses.init_pair(1, curses.COLOR_WHITE, curses.COLOR_BLUE)
 
-	# Disable the blinking cursor
+	# Disable the blinking cursor.
 	try:
 		curses.curs_set(False)
-	# Because some terminals do not support the invisible cursor, proceeed
-	# if curs_set fails to change the visibility
+	# Because some terminals do not support the invisible cursor, proceeed if `curs_set()` fails to change the visibility.
 	except Exception:
 		pass
 
@@ -244,7 +238,7 @@ def _init_screen(screen):
 
 def interactive_replace(plain_output: bool) -> int: # pylint: disable=unused-argument
 	"""
-	Entry point for `se interactive-replace`
+	Entry point for `se interactive-replace`.
 	"""
 
 	parser = argparse.ArgumentParser(description="Perform an interactive search and replace on a list of files using Python-flavored regex. The view is scrolled using the arrow keys, with alt to scroll by page in any direction. Basic Emacs (default) or Vim style navigation is available. The following actions are possible: (y) Accept replacement. (n) Reject replacement. (a) Accept all remaining replacements in this file. (r) Reject all remaining replacements in this file. (c) Center on match. (q) Save this file and quit.")
@@ -258,11 +252,10 @@ def interactive_replace(plain_output: bool) -> int: # pylint: disable=unused-arg
 	args = parser.parse_args()
 
 	# By default, the esc key has a delay before its delivered to curses.
-	# Set the delay to 0
+	# Set the delay to 0.
 	os.environ.setdefault("ESCDELAY", "0")
 
-	# Save errors for later, because we can only print them after curses is
-	# deinitialized
+	# Save errors for later, because we can only print them after curses is deinitialized.
 	errors = []
 	return_code = 0
 	screen = None
@@ -301,10 +294,10 @@ def interactive_replace(plain_output: bool) -> int: # pylint: disable=unused-arg
 			original_xhtml = xhtml
 			is_file_dirty = False
 
-			# Only init the screen if we actually have matches
+			# Only init the screen if we actually have matches.
 
 			# Do we have a regex match in the text?
-			# We only consider text after the last completed match
+			# We only consider text after the last completed match.
 			if regex.search(fr"{args.regex}", original_xhtml, flags=regex_flags):
 				screen = _init_screen(screen)
 			else:
@@ -314,15 +307,11 @@ def interactive_replace(plain_output: bool) -> int: # pylint: disable=unused-arg
 
 			# In curses terminology, a "pad" is a window that is larger than the viewport.
 			# Pads can be scrolled around.
-			# Create and output our initial pad
+			# Create and output our initial pad.
 			try:
 				pad, line_numbers_pad, pad_y, pad_x, match_start, match_end = _print_screen(screen, filepath, xhtml, 0, args.regex, regex_flags)
 			except curses.error as ex:
-				# Curses has a hard upper limit on the width of a pad, around 32k. If a line is too long,
-				# curses will crash with this error message. This happens in ebooks with very very long lines,
-				# like Proust. It's very rare for this to occur, so we just print an error instead of trying
-				# to solve the general case; the solution would probably involve soft-wrapping very long lines before
-				# sending to curses.
+				# Curses has a hard upper limit on the width of a pad, around 32k. If a line is too long, curses will crash with this error message. This happens in ebooks with very very long lines, like Proust. It's very rare for this to occur, so we just print an error instead of trying to solve the general case; the solution would probably involve soft-wrapping very long lines before sending to curses.
 				if str(ex) == "curses function returned NULL":
 					errors.append(f"File contains a line that is too long to process: {filepath}")
 					return_code = se.InvalidInputException.code
@@ -331,19 +320,19 @@ def interactive_replace(plain_output: bool) -> int: # pylint: disable=unused-arg
 				raise ex
 
 			while pad:
-				# Wait for input
+				# Wait for input.
 				char = pad.getch()
 
 				esc_pressed = False
 				alt_pressed = False
 
-				if char == 27: # ALT was pressed
+				if char == 27: # `alt` was pressed.
 					pad.nodelay(True)
 					alt_pressed = True
-					char = pad.getch() # Get the key pressed after ALT
+					char = pad.getch() # Get the key pressed after `alt`.
 					pad.nodelay(False)
 
-				if alt_pressed and char == -1: # ESC
+				if alt_pressed and char == -1: # `esc`.
 					esc_pressed = True
 
 				# We have input!
@@ -351,18 +340,18 @@ def interactive_replace(plain_output: bool) -> int: # pylint: disable=unused-arg
 				pad_height, pad_width = pad.getmaxyx()
 				_, line_numbers_width = line_numbers_pad.getmaxyx()
 
-				# Accept all remaining replacements and continue to the next file
+				# Accept all remaining replacements and continue to the next file.
 				if curses.keyname(char) in (b"a", b"A"):
 					xhtml = xhtml[:match_start] + regex.sub(fr"{args.regex}", fr"{args.replace}", xhtml[match_start:], flags=regex_flags)
 
-					# Can't check is_file_dirty, we have to compare file contents
+					# Can't check is_file_dirty, we have to compare file contents.
 					if xhtml != original_xhtml:
 						with open(filepath, "w", encoding="utf-8") as file:
 							file.write(xhtml)
 
 					break
 
-				# Reject all remaining replacements and continue to the next file
+				# Reject all remaining replacements and continue to the next file.
 				if curses.keyname(char) in (b"r", b"R") or esc_pressed:
 					if is_file_dirty:
 						with open(filepath, "w", encoding="utf-8") as file:
@@ -370,50 +359,45 @@ def interactive_replace(plain_output: bool) -> int: # pylint: disable=unused-arg
 
 					break
 
-				# Save this file and quit immediately
+				# Save this file and quit immediately.
 				if curses.keyname(char) in (b"q", b"Q"):
 					if is_file_dirty:
 						with open(filepath, "w", encoding="utf-8") as file:
 							file.write(xhtml)
 
-					# Throw a blank exception so that we break out of the loop
-					# and disinitialize curses in `finally`
+					# Throw a blank exception so that we break out of the loop and disinitialize curses in `finally`.
 					raise Exception # pylint: disable=broad-exception-raised
 
 				if curses.keyname(char) in (b"y", b"Y"):
-					# Do the replacement, but starting from the beginning of the match in case we
-					# skipped replacements earlier
+					# Do the replacement, but starting from the beginning of the match in case we skipped replacements earlier.
 					new_xhtml = xhtml[:match_start] + regex.sub(fr"{args.regex}", fr"{args.replace}", xhtml[match_start:], 1, flags=regex_flags)
 
-					# Our replacement has changed the XHTML string, so the
-					# match_end doesn't point to the right place any more.
-					# Update match_end to account for the change in string length
-					# caused by the replacement before passing it to _print_screen()
+					# Our replacement has changed the XHTML string, so the `match_end` doesn't point to the right place any more.
+					# Update `match_end` to account for the change in string length caused by the replacement before passing it to `_print_screen()`.
 					match_end = match_end + (len(new_xhtml) - len(xhtml))
 
 					is_file_dirty = True
 
-					# OK, now set our xhtml to the replaced version
+					# OK, now set our XHMTL to the replaced version.
 					xhtml = new_xhtml
 
 					pad, line_numbers_pad, pad_y, pad_x, match_start, match_end = _print_screen(screen, filepath, xhtml, match_end, args.regex, regex_flags)
 
 				if curses.keyname(char) in (b"n", b"N"):
-					# Skip this match
+					# Skip this match.
 					pad, line_numbers_pad, pad_y, pad_x, match_start, match_end = _print_screen(screen, filepath, xhtml, match_end, args.regex, regex_flags)
 
-				# Center on the match
+				# Center on the match.
 				if curses.keyname(char) in (b"c", b"C"):
 					pad_y, pad_x = _get_center_of_match(xhtml, match_start, match_end, screen_height, screen_width)
 
 					pad.refresh(pad_y, pad_x, 1, line_numbers_width, screen_height - 2, screen_width - 1)
 					line_numbers_pad.refresh(pad_y, 0, 1, 0, screen_height - 2, line_numbers_width)
 
-				# The terminal has been resized, redraw the UI
+				# The terminal has been resized, redraw the UI.
 				if curses.keyname(char) == b"KEY_RESIZE":
 					screen_height, screen_width = screen.getmaxyx()
-					# Note that we pass match_start instead of match_end to print screen, so that we don't
-					# appear to increment the search when we resize!
+					# Note that we pass `match_start` instead of `match_end` to print screen, so that we don't appear to increment the search when we resize!
 					pad, line_numbers_pad, pad_y, pad_x, _, _ = _print_screen(screen, filepath, xhtml, match_start, args.regex, regex_flags)
 
 				if curses.keyname(char) in (b"KEY_DOWN", nav_down):
@@ -428,7 +412,7 @@ def interactive_replace(plain_output: bool) -> int: # pylint: disable=unused-arg
 						pad.refresh(pad_y, pad_x, 1, line_numbers_width, screen_height - 2, screen_width - 1)
 						line_numbers_pad.refresh(pad_y, 0, 1, 0, screen_height - 2, line_numbers_width)
 
-				# pgdown or alt + down, which has its own keycode
+				# `pgdown` or `alt + down`, which has its own keycode.
 				if curses.keyname(char) in (b"KEY_NPAGE", b"kDN3") or (not args.vim and curses.keyname(char) == b"^V") or (args.vim and curses.keyname(char) == b"^F"):
 					if pad_height - pad_y - screen_height > 0:
 						pad_y = pad_y + screen_height
@@ -437,7 +421,7 @@ def interactive_replace(plain_output: bool) -> int: # pylint: disable=unused-arg
 						pad.refresh(pad_y, pad_x, 1, line_numbers_width, screen_height - 2, screen_width - 1)
 						line_numbers_pad.refresh(pad_y, 0, 1, 0, screen_height - 2, line_numbers_width)
 
-				# pgup or alt + up, which has its own keycode
+				# `pgup` or `alt + up`, which has its own keycode.
 				if curses.keyname(char) in (b"KEY_PPAGE", b"kUP3") or (not args.vim and alt_pressed and curses.keyname(char) == b"v") or (args.vim and curses.keyname(char) == b"^B"):
 					if pad_y > 0:
 						pad_y = max(pad_y - screen_height, 0)
@@ -454,7 +438,7 @@ def interactive_replace(plain_output: bool) -> int: # pylint: disable=unused-arg
 						pad_x = pad_x - 1
 						pad.refresh(pad_y, pad_x, 1, line_numbers_width, screen_height - 2, screen_width - 1)
 
-				# alt + right, which as its own key code
+				# `alt + right`, which as its own key code.
 				if curses.keyname(char) == b"kRIT3":
 					if pad_width - pad_x - screen_width + line_numbers_width > 1:
 						pad_x = pad_x + screen_width - line_numbers_width
@@ -462,7 +446,7 @@ def interactive_replace(plain_output: bool) -> int: # pylint: disable=unused-arg
 							pad_x = pad_width - screen_width + line_numbers_width - 1
 						pad.refresh(pad_y, pad_x, 1, line_numbers_width, screen_height - 2, screen_width - 1)
 
-				# alt + left, which as its own key code
+				# `alt + left`, which as its own key code.
 				if curses.keyname(char) == b"kLFT3":
 					if pad_x > 0:
 						pad_x = max(pad_x - screen_width, 0)
@@ -473,14 +457,12 @@ def interactive_replace(plain_output: bool) -> int: # pylint: disable=unused-arg
 					file.write(xhtml)
 
 	except Exception as ex:
-		# We check for the `pattern` attr instead of catching
-		# regex._regex_core.error because the regex error type is
-		# private and pylint will complain
+		# We check for the `pattern` attribute instead of catching `regex._regex_core.error` because the regex error type is private and pylint will complain.
 		if hasattr(ex, "pattern"):
 			errors.append(f"Invalid regular expression: {ex}")
 			return_code = se.InvalidInputException.code
 
-		# We may get here if we pressed `q`
+		# We may get here if we pressed `q`.
 	finally:
 		if screen is not None:
 			curses.endwin()
