@@ -11,7 +11,7 @@ import se.formatting
 
 def make_url_safe(plain_output: bool) -> int: # pylint: disable=unused-argument
 	"""
-	Entry point for `se make-url-safe`
+	Entry point for `se make-url-safe`.
 	"""
 
 	parser = argparse.ArgumentParser(description="Make a string URL-safe.")
