@@ -15,7 +15,7 @@ import se
 
 def unicode_names(plain_output: bool) -> int:
 	"""
-	Entry point for `se unicode-names`
+	Entry point for `se unicode-names`.
 	"""
 
 	parser = argparse.ArgumentParser(description="Display Unicode code points, descriptions, and links to more details for each character in a string. Useful for differentiating between different flavors of spaces, dashes, and invisible characters like word joiners.")
