@@ -1,10 +1,8 @@
 #!/usr/bin/env python3
 """
-This module contains the make-toc function which tries to create a
-valid table of contents file for SE projects.
+This module contains the make-toc function which tries to create a valid table of contents file for SE projects.
 
-Strictly speaking, the generate_toc() function should be a class member of SeEpub. But
-the function is very big and it makes editing easier to put in a separate file.
+Strictly speaking, the generate_toc() function should be a class member of SeEpub. But the function is very big and it makes editing easier to put in a separate file.
 """
 
 from enum import Enum
@@ -43,14 +41,13 @@ class Position(Enum):
 
 class TocItem:
 	"""
-	Small class to hold data on each table of contents item
-	found in the project.
+	Small class to hold data on each table of contents item found in the project.
 	"""
 
 	# pylint: disable=too-many-instance-attributes
 
 	file_link = ""
-	hidden = False # Did the <h#> element have the `hidden` attribute? If so, that means we MUST include it as a subtitle
+	hidden = False # Did the `<h#>` element have the `hidden` attribute? If so, that means we *must* include it as a subtitle.
 	level = 0
 	roman = ""
 	title = ""
@@ -69,10 +66,10 @@ class TocItem:
 		Generates the hyperlink for the ToC item.
 
 		INPUTS:
-		None
+		None.
 
 		OUTPUTS:
-		the linking tag line eg <a href=... depending on the data found.
+		The linking tag line, e.g. `<a href=...` depending on the data found.
 		"""
 
 		out_string = ""
@@ -80,46 +77,46 @@ class TocItem:
 			raise se.InvalidInputException(f"Couldn’t find title in: [path][link=file://{self.file_link}]{self.file_link}[/][/].")
 
 		if self.subtitle and self.lang:
-			# test for a foreign language subtitle, and adjust accordingly
+			# Test for a foreign language subtitle, and adjust accordingly.
 			self.subtitle = f"<span xml:lang=\"{self.lang}\">{self.subtitle}</span>"
 
-		# If the title is entirely Roman numeral, put epub:type within <a>.
+		# If the title is entirely roman numeral, put epub:type within `<a>`.
 		if regex.search(r"^<span epub:type=\"z3998:roman\">[IVXLC]+<\/span>$", self.title):
-			# title is a pure roman number
-			if self.subtitle == "":  # put the roman flag inside the <a> tag
+			# Title is a pure roman numeral.
+			if self.subtitle == "":  # Put the roman flag inside the `<a>` element.
 				out_string += f"<a href=\"text/{self.file_link}\" epub:type=\"z3998:roman\">{self.roman}</a>\n"
 			else:
 				out_string += f"<a href=\"text/{self.file_link}\"><span epub:type=\"z3998:roman\">{self.roman}</span>: {self.subtitle}</a>\n"
 		else:
-			# Title has text other than a roman numeral
+			# Title has text other than a roman numeral.
 			if self.subtitle != "" and (self.hidden or self.title_is_ordinal or (self.division in [BookDivision.PART, BookDivision.DIVISION, BookDivision.VOLUME])):
-				# Use the subtitle only if we're a Part or Division or Volume or if title was an ordinal
+				# Use the subtitle only if we're a Part or Division or Volume or if title was an ordinal.
 				out_string += f"<a href=\"text/{self.file_link}\">{self.title}"
 
-				# Don't append a colon if the ordinal already ends in punctuation, for example  `1.` or `(a)`
+				# Don't append a colon if the ordinal already ends in punctuation, for example `1.` or `(a)`.
 				if not regex.search(r"\p{Punctuation}$", self.title):
 					out_string += ":"
 
 				out_string += f" {self.subtitle}</a>\n"
 			else:
-				# Test for a foreign language title, and adjust accordingly
+				# Test for a foreign language title, and adjust accordingly.
 				if self.lang:
 					out_string += f"<a href=\"text/{self.file_link}\" xml:lang=\"{self.lang}\">{self.title}</a>\n"
 				else:
 					out_string += f"<a href=\"text/{self.file_link}\">{self.title}</a>\n"
 
-		# Replace <br/> with a single space
+		# Replace `<br/>` with a single space.
 		out_string = regex.sub(r"<br/>\s*", " ", out_string)
 
 		return out_string
 
 	def landmark_link(self, work_title: str = "WORK_TITLE") -> str:
 		"""
-		Generates the landmark item (including list item tags) for the ToC item
+		Generates the landmark item (including list item tags) for the ToC item.
 
 		INPUTS:
-		work_type: ("fiction" or "non-fiction")
-		work_title: the title of the book, eg "Don Quixote"
+		work_type: `fiction` or `non-fiction`.
+		work_title: the title of the book, eg `Don Quixote`.
 
 		OUTPUTS:
 		the linking string to be included in landmarks section.
@@ -140,10 +137,10 @@ def get_place(node: EasyXmlElement) -> Position:
 	Returns place of file in ebook, eg frontmatter, backmatter, etc.
 
 	INPUTS:
-	node: EasyXmlElement representation of the file
+	node: `EasyXmlElement` representation of the file.
 
 	OUTPUTS:
-	a Position enum value indicating the place in the book
+	a `Position` enum value indicating the place in the book.
 	"""
 
 	epub_type = node.get_attr("epub:type")
@@ -166,17 +163,17 @@ def add_landmark(dom: EasyXmlTree, textf: str, landmarks: list) -> None:
 	Adds an item to landmark list with appropriate details.
 
 	INPUTS:
-	dom: EasyXmlTree representation of the file we are indexing in ToC
-	textf: path to the file
-	landmarks: the list of landmark items we are building
+	dom: `EasyXmlTree` representation of the file we are indexing in ToC.
+	textf: path to the file.
+	landmarks: the list of landmark items we are building.
 
 	OUTPUTS:
 	None
 	"""
 
 	# According to the IDPF a11y best practices page: <http://idpf.org/epub/a11y/techniques/#sem-003>:
-	# > it is recommended to include a link to the start of the body matter as well as to any major
-	# > reference sections (e.g., table of contents, endnotes, bibliography, glossary, index).
+	#
+	# > it is recommended to include a link to the start of the body matter as well as to any major reference sections (e.g., table of contents, endnotes, bibliography, glossary, index).
 	#
 	# So, we only want the start of the text, and (endnotes,glossary,bibliography,loi) in the landmarks.
 
@@ -189,21 +186,21 @@ def add_landmark(dom: EasyXmlTree, textf: str, landmarks: list) -> None:
 	if not bodys:
 		raise se.InvalidInputException("Couldn’t locate [xhtml]<body>[/].")
 
-	if not epub_type:  # some productions don't have an epub:type in outermost section, so get it from body tag
+	if not epub_type:  # Some productions don't have an epub:type in outermost section, so get it from `<body>` element.
 		epub_type = bodys[0].get_attr("epub:type")
 		if not epub_type:
 			epub_type = ""
 
 	if epub_type in ["frontmatter", "bodymatter", "backmatter"]:
-		return  # if epub_type is ONLY frontmatter, bodymatter, backmatter, we don't want this as a landmark
+		return  # If `epub_type` is *only* `frontmatter`, `bodymatter`, `backmatter`, we don't want this as a landmark.
 
 	if dom.xpath("//*[contains(@epub:type, 'frontmatter')]"):
-		return # We don't want frontmatter in the landmarks
+		return # We don't want frontmatter in the landmarks.
 
 	if dom.xpath("//*[contains(@epub:type, 'backmatter')]") and not regex.search(r"\b(loi|endnotes|bibliography|glossary|index)\b", epub_type):
-		return # We only want certain backmatter in the landmarks
+		return # We only want certain backmatter in the landmarks.
 
-	# We may wind up with a (front|body|back)matter semantic in epub_type, remove it here since we add it to the landmark later
+	# We may wind up with a `(front|body|back)matter` semantic in `epub_type`, remove it here since we add it to the landmark later.
 	epub_type = regex.sub(r"(front|body|back)matter\s*", "", epub_type)
 
 	landmark = TocItem()
@@ -215,13 +212,13 @@ def add_landmark(dom: EasyXmlTree, textf: str, landmarks: list) -> None:
 		if epub_type == "halftitlepage":
 			landmark.title = "Half Title"
 		elif epub_type == "titlepage":
-			# Exception: The titlepage always is always titled 'titlepage' in the ToC
+			# Exception: The titlepage always is always titled `titlepage` in the ToC.
 			landmark.title = "Titlepage"
 			landmark.lang = "" # Reset the language in case the ebook is title is not English.
 		else:
 			landmark.title = dom.xpath("//head/title/text()", True)  # Use the page title as the landmark entry title.
 			if landmark.title is None:
-				# This is a bit desperate, use this only if there's no proper <title> tag in file.
+				# This is a bit desperate, use this only if there's no proper `<title>` element in file.
 				landmark.title = landmark.epub_type.capitalize()
 
 		landmarks.append(landmark)
@@ -231,12 +228,12 @@ def process_landmarks(landmarks_list: list, work_title: str) -> str:
 	Runs through all found landmark items and writes them to the toc file.
 
 	INPUTS:
-	landmarks_list: the completed list of landmark items
-	work_type: "fiction" or "non-fiction"
-	work_title: the title of the book
+	landmarks_list: the completed list of landmark items.
+	work_type: `fiction` or `non-fiction`.
+	work_title: the title of the book.
 	"""
 
-	# we don't want frontmatter items to be included once we've started the body items
+	# We don't want frontmatter items to be included once we've started the body items.
 	started_body = False
 	for item in landmarks_list:
 		if item.place == Position.BODY:
@@ -263,10 +260,10 @@ def process_items(item_list: list) -> str:
 	Runs through all found toc items and returns them as a string.
 
 	INPUTS:
-	item_list: list of ToC items
+	item_list: list of ToC items.
 
 	OUTPUTS:
-	A string representing (possibly nested) html lists of the structure of the ToC
+	A string representing (possibly nested) HTML lists of the structure of the ToC.
 	"""
 
 	unclosed_ol = 0  # Keep track of how many ordered lists we open.
@@ -283,19 +280,19 @@ def process_items(item_list: list) -> str:
 			out_string += this_item.toc_link
 			out_string += "</li>\n"
 
-		if next_item.level > this_item.level:  # PARENT, start a new ol list
+		if next_item.level > this_item.level:  # Parent, start a new `<ol>` list.
 			out_string += "<li>\n"
 			out_string += this_item.toc_link
 			out_string += "<ol>\n"
 			unclosed_ol += 1
 
-		if next_item.level < this_item.level:  # LAST CHILD, close off the list
+		if next_item.level < this_item.level:  # Last child, close off the list.
 			out_string += "<li>\n"
 			out_string += this_item.toc_link
 			out_string += "</li>\n"  # Close off this item.
 			torepeat = this_item.level - next_item.level
-			while torepeat and unclosed_ol:  # neither can go below zero
-				# We need to repeat a few times as may be jumping back from eg h5 to h2
+			while torepeat and unclosed_ol:  # Neither can go below zero.
+				# We need to repeat a few times as may be jumping back from e.g. `<h5>` to `<h2>`.
 				out_string += "</ol>\n"  # End of embedded list.
 				out_string += "</li>\n"  # End of parent item.
 				unclosed_ol -= 1
@@ -306,17 +303,16 @@ def process_items(item_list: list) -> str:
 
 def output_toc(item_list: list, landmark_list, toc_path: str, work_title: str) -> str:
 	"""
-	Outputs the contructed ToC based on the lists of items and landmarks found,
-	either to stdout or overwriting the existing ToC file
+	Outputs the contructed ToC based on the lists of items and landmarks found, either to stdout or overwriting the existing ToC file.
 
 	INPUTS:
-	item_list: list of ToC items (the first part of the ToC)
-	landmark_list: list of landmark items (the second part of the ToC)
-	work_type: "fiction" or "non-fiction"
-	work_title: the title of the book
+	item_list: list of ToC items (the first part of the ToC).
+	landmark_list: list of landmark items (the second part of the ToC).
+	work_type: `fiction` or `non-fiction`.
+	work_title: the title of the book.
 
 	OUTPUTS:
-	a html string representing the new ToC
+	A HTML string representing the new ToC.
 	"""
 
 	if len(item_list) < 2:
@@ -334,13 +330,13 @@ def output_toc(item_list: list, landmark_list, toc_path: str, work_title: str) -
 	if len(navs) < 2:
 		raise se.InvalidInputException("Existing ToC has too few nav sections.")
 
-	# now remove and then re-add the ol sections to clear them
+	# Now remove and then re-add the `<ol>` sections to clear them.
 	for nav in navs:
-		ols = nav.xpath("./ol")  # just want the immediate ol children
+		ols = nav.xpath("./ol")  # Just want the immediate `<ol>` children.
 		for ol_item in ols:
 			ol_item.remove()
 
-	# this is ugly and stupid, but I can't figure out an easier way to do it
+	# This is ugly and stupid, but I can't figure out an easier way to do it.
 	item_ol = EasyXmlElement(etree.Element("ol"), toc_dom.namespaces)
 	item_ol.lxml_element.text = "TOC_ITEMS"
 	navs[0].append(item_ol)
@@ -355,16 +351,16 @@ def output_toc(item_list: list, landmark_list, toc_path: str, work_title: str) -
 
 def get_parent_id(hchild: EasyXmlElement) -> str:
 	"""
-	Climbs up the document tree looking for parent id in a <section> tag.
+	Climbs up the document tree looking for parent ID in a `<section>` element.
 
 	INPUTS:
-	hchild: a heading tag for which we want to find the parent id
+	hchild: a heading element for which we want to find the parent ID.
 
 	OUTPUTS:
-	the id of the parent section
+	The ID of the parent section.
 	"""
 
-	# position() = 1 gets the nearest ancestor
+	# `position() = 1` gets the nearest ancestor.
 	parents = hchild.xpath("./ancestor::*[name() = 'section' or name() = 'article'][@id][position() = 1]")
 
 	if parents:
@@ -374,13 +370,13 @@ def get_parent_id(hchild: EasyXmlElement) -> str:
 
 def extract_strings(node: EasyXmlElement) -> str:
 	"""
-	Returns string representation of a tag, ignoring linefeeds
+	Returns string representation of an element, ignoring linefeeds.
 
 	INPUTS:
-	node: a tag as xpath node
+	node: An xpath node.
 
 	OUTPUTS:
-	just the string contents of the tag
+	Just the string contents of the element.
 	"""
 
 	out_string = node.inner_xml()
@@ -390,17 +386,16 @@ def extract_strings(node: EasyXmlElement) -> str:
 
 def process_headings(dom: EasyXmlTree, textf: str, toc_list: list, single_file: bool, single_file_without_headers: bool) -> None:
 	"""
-	Find headings in current file and extract title data
-	into items added to toc_list.
+	Find headings in current file and extract title data into items added to `toc_list`.
 
 	INPUTS:
-	dom: an EasyXmlTree representation of the current file
-	textf: the path to the file
-	toc_list: the list of ToC items we are building
-	single_file: is there only a single content item in the production?
+	dom: An `EasyXmlTree` representation of the current file.
+	textf: The path to the file.
+	toc_list: The list of ToC items we are building.
+	single_file: Is there only a single content item in the production?
 
 	OUTPUTS:
-	None
+	None.
 	"""
 
 	body = dom.xpath("//body")
@@ -412,20 +407,20 @@ def process_headings(dom: EasyXmlTree, textf: str, toc_list: list, single_file:
 
 	is_toplevel = True
 
-	# Find all the hgroups and h1, h2 etc headings.
+	# Find all the `<hgroup>`s and `<h#>` headings.
 	heads = dom.xpath("//hgroup | //h1 | //h2 | //h3 | //h4 | //h5 | //h6")
 
-	# special treatment where we can't find any heading or hgroups
-	if not heads:  # May be a dedication or an epigraph, with no heading tag.
+	# Special treatment where we can't find any heading or `<hgroup>`s.
+	if not heads:  # May be a dedication or an epigraph, with no heading element.
 		special_item = TocItem()
 		# Need to determine level depth.
-		# We don't have a heading, so get first content item
+		# We don't have a heading, so get first content item.
 		content_item = dom.xpath("//p | //header | //img")
-		if content_item: # check to see if it has a data-parent, if so, we'll use that to determine depth
+		if content_item: # Check to see if it has a `data-parent` attribute, if so, we'll use that to determine depth.
 			data_parent = content_item[0].xpath("//*[@data-parent]")
 			if data_parent:
 				special_item.level = get_level(content_item[0], toc_list)
-			else: # special items without data-parents get a default dept of 1
+			else: # Special items without `data-parents` get a default dept of 1.
 				special_item.level = 1
 		else:
 			raise se.InvalidInputException(f"Unable to find heading or content item (p, header or img) in file: [path][link=file://{textf}]{textf}[/][/].")
@@ -434,36 +429,32 @@ def process_headings(dom: EasyXmlTree, textf: str, toc_list: list, single_file:
 			special_item.title = "NO TITLE"
 		special_item.file_link = textf
 		special_item.toc_id = get_toc_id_for_special_item(content_item[0])
-		if not special_item.toc_id: # no luck so use quick and dirty method
+		if not special_item.toc_id: # No luck so use quick and dirty method.
 			special_item.toc_id = textf.replace('.xhtml','')
 		special_item.place = place
 		toc_list.append(special_item)
 		return
 
 	for heading in heads:
-		# don't process a heading separately if it's within a hgroup
+		# Don't process a heading separately if it's within a `<hgroup>`.
 		if heading.parent.tag == "hgroup":
-			continue  # skip it
+			continue  # Skip it.
 
 		if place == Position.BODY:
 			toc_item = process_a_heading(heading, textf, is_toplevel, single_file)
 		else:
-			# if it's not a bodymatter item we don't care about whether it's single_file
+			# If it's not a bodymatter item we don't care about whether it's `single_file`.
 			toc_item = process_a_heading(heading, textf, is_toplevel, False)
 
 		toc_item.level = get_level(heading, toc_list)
 		toc_item.place = place
 
-		# Exception: The titlepage always has is titled 'titlepage' in the ToC
+		# Exception: The titlepage always has is titled `titlepage` in the ToC.
 		if dom.xpath("//section[re:test(@epub:type, '\\btitlepage\\b')]"):
 			toc_item.title = "Titlepage"
 			toc_item.lang = "" # Reset in case the title is not English.
 
-		# Exception: If there is only a single body item WITHOUT HEADERS (like Father Goriot or The Path to Rome),
-		# the half title page is listed as "Half-Titlepage" instead of the work title,
-		# so that we don't duplicate the work title in the ToC. We always include a link to the work body
-		# in the ToC because readers on the web version need to have access to the text starting point, since
-		# there are no back/forward nav buttons in XHTML files served on the web.
+		# Exception: If there is only a single body item *without headers* (like _Father Goriot_ or _The Path to Rome_), the half title page is listed as `Half-Titlepage` instead of the work title, so that we don't duplicate the work title in the ToC. We always include a link to the work body in the ToC because readers on the web version need to have access to the text starting point, since there are no back/forward nav buttons in XHTML files served on the web.
 		if single_file_without_headers and dom.xpath("//section[re:test(@epub:type, '\\bhalftitlepage\\b')]"):
 			toc_item.title = "Half-Titlepage"
 
@@ -473,7 +464,7 @@ def process_headings(dom: EasyXmlTree, textf: str, toc_list: list, single_file:
 
 def get_toc_id_for_special_item(node: EasyXmlElement) -> str:
 	"""
-	Get the id for a 'special item' node
+	Get the id for a 'special item' node.
 	"""
 	parent_sections = node.xpath("./ancestor::*[name() = 'section' or name() = 'article']")
 	for parent in parent_sections:
@@ -488,7 +479,7 @@ def get_level(node: EasyXmlElement, toc_list: list) -> int:
 	Get level of a node.
 	"""
 
-	# first need to check how deep this heading is within the current file
+	# First need to check how deep this heading is within the current file.
 	parent_sections = node.xpath("./ancestor::*[name() = 'section' or name() = 'article']")
 	if parent_sections:
 		depth = len(parent_sections)
@@ -496,7 +487,7 @@ def get_level(node: EasyXmlElement, toc_list: list) -> int:
 		depth = 1
 
 	if not node.parent:
-		return depth  # must be at the top level
+		return depth  # Must be at the top level.
 
 	data_parents = node.xpath("//*[@data-parent]")
 	if not data_parents:
@@ -505,11 +496,11 @@ def get_level(node: EasyXmlElement, toc_list: list) -> int:
 	data_parent = data_parents[0].get_attr("data-parent")
 
 	if data_parent:
-		# see if we can find it in already processed (as we should if spine is correctly ordered)
+		# See if we can find it in already processed (as we should if spine is correctly ordered).
 		parent_file = [t for t in toc_list if t.toc_id == data_parent]
 		if parent_file:
 			this_level = parent_file[0].level + 1
-			return this_level + depth - 1  # subtract from depth because all headings should have depth >= 1
+			return this_level + depth - 1  # Subtract from depth because all headings should have depth >= 1.
 
 	return depth
 
@@ -518,20 +509,20 @@ def process_a_heading(node: EasyXmlElement, textf: str, is_toplevel: bool, singl
 	Generate and return a single TocItem from this heading.
 
 	INPUTS:
-	node: an EasyXml node representing a heading
-	text: the path to the file
-	is_toplevel: is this heading at the top-most level in the file?
-	single_file: is there only one content file in the production (like some Poetry volumes)?
+	node: An `EasyXml` node representing a heading.
+	text: The path to the file.
+	is_toplevel: Is this heading at the top-most level in the file?
+	single_file: Is there only one content file in the production (like some Poetry volumes)?
 
 	OUTPUTS:
-	a qualified ToCItem object
+	A qualified `TocItem` object.
 	"""
 
 	toc_item = TocItem()
 
 	toc_item.division = get_book_division(node)
 
-	# is_top_level stops the first heading in a file getting an anchor id, we don't generally want that.
+	# `is_top_level` stops the first heading in a file getting an anchor id, we don't generally want that.
 	# The exceptions are things like poems within a single-file volume.
 	toc_item.toc_id = get_parent_id(node)  # pylint: disable=invalid-name
 	if toc_item.toc_id == "":
@@ -539,7 +530,7 @@ def process_a_heading(node: EasyXmlElement, textf: str, is_toplevel: bool, singl
 	else:
 		if not is_toplevel:
 			toc_item.file_link = f"{textf}#{toc_item.toc_id}"
-		elif single_file:  # It IS the first heading in the file, but there's only a single content file?
+		elif single_file:  # It *is* the first heading in the file, but there's only a single content file?
 			toc_item.file_link = f"{textf}#{toc_item.toc_id}"
 		else:
 			toc_item.file_link = textf
@@ -551,17 +542,16 @@ def process_a_heading(node: EasyXmlElement, textf: str, is_toplevel: bool, singl
 
 	epub_type = node.get_attr("epub:type")
 
-	# it may be an empty header tag eg <h3>, so we pass its parent rather than itself to evaluate the parent's descendants
+	# It may be an empty header element eg `<h3>`, so we pass its parent rather than itself to evaluate the parent's descendants.
 	if not epub_type and node.tag in ["h1", "h2", "h3", "h4", "h5", "h6"]:
 		parent = node.parent
 		if parent:
 			evaluate_descendants(parent, toc_item, textf)
-		else:  # shouldn't ever happen, but... just in case, raise an error
+		else:  # Shouldn't ever happen, but... just in case, raise an error.
 			raise se.InvalidInputException(f"Heading without parent in file: [path][link=file://{textf}]{textf}[/][/].")
 		return toc_item
 	if epub_type:
-		# A heading may include z3998:roman directly,
-		# eg <h5 epub:type="title z3998:roman">II</h5>.
+		# A heading may include `z3998:roman` directly, e.g. `<h5 epub:type="title z3998:roman">II</h5>`.
 		if "z3998:roman" in epub_type:
 			toc_item.roman = extract_strings(node)
 			try:
@@ -570,20 +560,20 @@ def process_a_heading(node: EasyXmlElement, textf: str, is_toplevel: bool, singl
 				raise se.InvalidInputException(f"Heading tagged as roman numeral is invalid: {toc_item.roman} in [path][link=file://{textf}]{textf}[/][/].") from err
 			toc_item.title = f"<span epub:type=\"z3998:roman\">{toc_item.roman}</span>"
 			return toc_item
-		if "ordinal" in epub_type:  # but not a roman numeral (eg in Nietzche's Beyond Good and Evil)
+		if "ordinal" in epub_type:  # But not a roman numeral (e.g. in Nietzche's _Beyond Good and Evil_).
 			toc_item.title = extract_strings(node)
 			toc_item.title_is_ordinal = True
 			return toc_item
-		# may be the halftitle page with a subtitle, so we need to burrow down
+		# May be the halftitle page with a subtitle, so we need to burrow down.
 		if ("fulltitle" in epub_type) and (node.tag == "hgroup"):
 			evaluate_descendants(node, toc_item, textf)
 			return toc_item
-		# or it may be a straightforward one-level title eg: <h2 epub:type="title">Imprint</h2>
+		# Or it may be a straightforward one-level title eg: `<h2 epub:type="title">Imprint</h2>`.
 		if "title" in epub_type:
 			toc_item.title = extract_strings(node)
 			return toc_item
 
-	# otherwise, burrow down into its structure to get the info
+	# Otherwise, burrow down into its structure to get the info.
 	evaluate_descendants(node, toc_item, textf)
 
 	return toc_item
@@ -591,7 +581,7 @@ def process_a_heading(node: EasyXmlElement, textf: str, is_toplevel: bool, singl
 
 def get_child_strings(node: EasyXmlElement) -> str:
 	"""
-	Get child strings
+	Get child strings.
 	"""
 
 	children = node.xpath("./*")
@@ -603,40 +593,40 @@ def get_child_strings(node: EasyXmlElement) -> str:
 
 def evaluate_descendants(node: EasyXmlElement, toc_item: TocItem, textf: str) -> TocItem:
 	"""
-	Burrow down into a hgroup structure to qualify the ToC item
+	Burrow down into a hgroup structure to qualify the ToC item.
 
 	INPUTS:
-	node: EasyXmlElement object representing a hgroup
+	node: `EasyXmlElement` object representing a `<hgroup>`.
 
 	OUTPUTS:
-	toc_item: qualified ToC item
+	toc_item: Qualified ToC item.
 	"""
 	children = node.xpath("./p | ./h1 | ./h2 | ./h3 | ./h4 | ./h5 | ./h6")
-	for child in children:  # we expect these to be h1, h2, h3, h4 etc
+	for child in children:  # We expect these to be an `<h#>`.
 		epub_type = child.get_attr("epub:type")
 
 		if child.get_attr("hidden"):
 			toc_item.hidden = True
 
 		if not epub_type:
-			# should be a label/ordinal grouping
+			# Should be a label/ordinal grouping.
 			child_strings = get_child_strings(child)
-			if "label" in child_strings and "ordinal" in child_strings:  # quick test
+			if "label" in child_strings and "ordinal" in child_strings:
 				toc_item.title_is_ordinal = True
-				# strip label
+				# Strip label.
 				child_strings = regex.sub(r"<span epub:type=\"label\">(.*?)</span>", " \\1 ", child_strings)
-				# remove ordinal if it's by itself in a span
+				# Remove ordinal if it's by itself in a `<span>`.
 				child_strings = regex.sub(r"<span epub:type=\"ordinal\">(.*?)</span>", " \\1 ", child_strings)
-				# remove ordinal if it's joined with a roman (which we want to keep)
+				# Remove ordinal if it's joined with a roman numeral (which we want to keep).
 				child_strings = regex.sub(r"\bordinal\b", "", child_strings)
-				# remove extra spaces
+				# Remove extra spaces.
 				child_strings = regex.sub(r"[ ]{2,}", " ", child_strings)
-				# remove any carriage returns
+				# Remove any carriage returns.
 				child_strings = regex.sub(r"\n", "", child_strings)
-				# get rid of any endnotes
+				# Get rid of any endnotes.
 				child_strings = strip_notes(child_strings)
 				toc_item.title = child_strings.strip()
-			continue  # skip the following
+			continue  # Skip the following.
 		if "z3998:roman" in epub_type:
 			toc_item.roman = extract_strings(child)
 			try:
@@ -645,37 +635,36 @@ def evaluate_descendants(node: EasyXmlElement, toc_item: TocItem, textf: str) ->
 				raise se.InvalidInputException(f"Heading tagged as roman numeral is invalid: {toc_item.roman} in [path][link=file://{textf}]{textf}[/][/].") from err
 			if not toc_item.title:
 				toc_item.title = f"<span epub:type=\"z3998:roman\">{toc_item.roman}</span>"
-		elif "ordinal" in epub_type:  # but not a roman numeral or a labelled item, cases caught caught above
+		elif "ordinal" in epub_type:  # But not a roman numeral or a labeled item, cases caught caught above.
 			if not toc_item.title:
 				toc_item.title = extract_strings(child)
 				toc_item.title_is_ordinal = True
 		if "subtitle" in epub_type:
 			toc_item.subtitle = extract_strings(child)
 		else:
-			if "title" in epub_type:  # this allows for `fulltitle` to work here, too
-				if toc_item.title or toc_item.roman or toc_item.title_is_ordinal:  # if title already filled, must be a subtitle
+			if "title" in epub_type:  # This allows for `fulltitle` to work here, too.
+				if toc_item.title or toc_item.roman or toc_item.title_is_ordinal:  # If the title is already filled, must be a subtitle.
 					toc_item.subtitle = extract_strings(child)
-					if toc_item.roman or toc_item.title_is_ordinal:  # in these cases, we want to check language on subtitle
+					if toc_item.roman or toc_item.title_is_ordinal:  # In these cases, we want to check language on subtitle.
 						toc_item.lang = child.get_attr("xml:lang")
 				else:
 					toc_item.title = extract_strings(child)
 					if not toc_item.lang:
 						toc_item.lang = child.get_attr("xml:lang")
 
-		if toc_item.title and toc_item.subtitle:  # then we're done, get out of loop by returning
+		if toc_item.title and toc_item.subtitle:  # Then we're done, get out of loop by returning.
 			return toc_item
 	return toc_item
 
 def get_book_division(node: EasyXmlElement) -> BookDivision:
 	"""
-	Determine the kind of book division. At present only Part and Division
-	are important; but others stored for possible future logic.
+	Determine the kind of book division. At present only Part and Division are important; but others stored for possible future logic.
 
 	INPUTS:
-	tag: an EasyXml node representing a tag
+	tag: An `EasyXml` node representing a nelement.
 
 	OUTPUTS:
-	a BookDivision enum value representing the kind of division
+	A `BookDivision` enum value representing the kind of division.
 	"""
 
 	parent_sections = node.xpath("./ancestor::*[name() = 'section' or name() = 'article']")
@@ -683,7 +672,7 @@ def get_book_division(node: EasyXmlElement) -> BookDivision:
 	if not parent_sections:
 		parent_sections = node.xpath("./ancestor::body")
 
-	if not parent_sections:  # couldn't find a parent, so throw an error
+	if not parent_sections:  # Couldn't find a parent, so throw an error.
 		raise se.InvalidInputException
 
 	section_epub_type = parent_sections[-1].get_attr("epub:type")
@@ -711,32 +700,30 @@ def strip_notes(text: str) -> str:
 	Returns html text stripped of noterefs.
 
 	INPUTS:
-	text: html which may include noterefs
+	text: HTMl which may include noterefs.
 
 	OUTPUTS:
-	cleaned html string
+	Cleaned HTMl string.
 	"""
 
 	return regex.sub(r"""<a[^>]*?epub:type="noteref"[^>]*?>.*?<\/a>""", "", text)
 
 def process_all_content(self, file_list: list) -> Tuple[list, list]:
 	"""
-	Analyze the whole content of the project, build and return lists
-	if toc_items and landmarks.
+	Analyze the whole content of the project, build and return lists of `toc_items` and landmarks.
 
 	INPUTS:
-	file_list: a list of all content files
-	text_path: the path to the contents folder (src/epub/text)
+	file_list: A list of all content files.
+	text_path: The path to the contents folder (e.g. `src/epub/text`).
 
 	OUTPUTS:
-	a tuple containing the list of Toc items and the list of landmark items
+	A tuple containing the list of Toc items and the list of landmark items.
 	"""
 
 	toc_list: List[TocItem] = []
 	landmarks: List[TocItem] = []
 
-	# We make two passes through the work, because we need to know
-	# how many bodymatter items there are. So we do landmarks first.
+	# We make two passes through the work, because we need to know how many bodymatter items there are. So we do landmarks first.
 	for textf in file_list:
 		try:
 			dom = self.get_dom(textf)
@@ -745,7 +732,7 @@ def process_all_content(self, file_list: list) -> Tuple[list, list]:
 
 		add_landmark(dom, textf.name, landmarks)
 
-	# Now we test to see if there is only one body item
+	# Now we test to see if there is only one body item.
 	body_items = [item for item in landmarks if item.place == Position.BODY]
 	single_file = len(body_items) == 1
 	single_file_without_headers = False
@@ -760,13 +747,13 @@ def process_all_content(self, file_list: list) -> Tuple[list, list]:
 		with open(textf, "r", encoding="utf-8") as file:
 			dom = se.easy_xml.EasyXmlTree(file.read())
 		process_headings(dom, textf.name, toc_list, single_file, single_file_without_headers)
-		# Only consider half title pages that are front matter. Some books, like C.S. Lewis Poetry, may have half titles that are bodymatter
+		# Only consider half title pages that are front matter. Some books, like C.S. Lewis's _Poetry_, may have half titles that are bodymatter.
 		if dom.xpath("/html/body//*[contains(@epub:type, 'halftitlepage') and ancestor-or-self::*[contains(@epub:type, 'frontmatter')]]"):
 			nest_under_halftitle = True
 
-	# now go through adjusting for nesting under halftitle
+	# Now go through adjusting for nesting under halftitle.
 	if nest_under_halftitle:
-		# tricky because a few books have forewords, etc AFTER the halftitle, so have to know if we've passed it
+		# Tricky because a few books have forewords, etc. *after* the halftitle, so have to know if we've passed it.
 		passed_halftitle = False
 		for toc_item in toc_list:
 			if toc_item.place == Position.BODY:
@@ -790,7 +777,7 @@ def generate_toc(self) -> str:
 	Entry point for `SeEpub.generate_toc()`.
 	"""
 
-	work_title = self.get_work_title()
+	work_title = self.get_title()
 
 	landmarks, toc_list = process_all_content(self, self.spine_file_paths)
 
