@@ -8,11 +8,11 @@ import importlib.resources
 import regex
 import se
 
-DICTIONARY: Set[str] = set()	# Store our hyphenation dictionary so we don't re-read the file on every pass
+DICTIONARY: Set[str] = set()	# Store our hyphenation dictionary so we don't re-read the file on every pass.
 
 def get_xhtml_language(xhtml: str) -> str:
 	"""
-	Try to get the IETF lang tag for a complete XHTML document
+	Try to get the IETF lang tag for a complete XHTML document.
 	"""
 
 	supported_languages = ["en-US", "en-GB", "en-AU", "en-CA", "en-IE"]
@@ -46,10 +46,10 @@ def modernize_hyphenation(xhtml: str) -> str:
 	Convert old-timey hyphenated compounds into single words based on the passed DICTIONARY.
 
 	INPUTS
-	xhtml: A string of XHTML to modernize
+	xhtml: A string of XHTML to modernize.
 
 	OUTPUTS
-	A string representing the XHTML with its hyphenation modernized
+	A string representing the XHTML with its hyphenation modernized.
 	"""
 
 	dictionary = initialize_dictionary()
@@ -57,20 +57,18 @@ def modernize_hyphenation(xhtml: str) -> str:
 	# Easy fix for a common case
 	xhtml = regex.sub(r"\b([Nn])ow-a-days\b", r"\1owadays", xhtml)	# now-a-days -> nowadays
 
-	# The non-capturing group at the beginning tries to prevent
-	# bad matches like stag's-horn -> stag'shorn or dog's-eared -> dog'seared
+	# The non-capturing group at the beginning tries to prevent bad matches like stag's-horn -> stag'shorn or dog's-eared -> dog'seared
 	result = regex.findall(r"(?<![’\'])\b[^\W\d_]+\-[^\W\d_]+\b", xhtml)
 
-	for word in set(result): # set() removes duplicates
+	for word in set(result): # `set()` removes duplicates.
 		new_word = word.replace("-", "").lower()
 		if new_word in dictionary:
-			# To preserve capitalization of the first word, we get the individual parts
-			# then replace the original match with them joined together and titlecased.
+			# To preserve capitalization of the first word, we get the individual parts then replace the original match with them joined together and titlecased.
 			lhs = regex.sub(r"\-.+$", r"", word)
 			rhs = regex.sub(r"^.+?\-", r"", word)
 			xhtml = regex.sub(fr"{lhs}-{rhs}", lhs + rhs.lower(), xhtml)
 
-	# Quick fix for a common error cases
+	# Quick fix for a common error cases.
 	xhtml = xhtml.replace("z3998:nonfiction", "z3998:non-fiction")
 	xhtml = regex.sub(r"\b([Mm])anat-arms", r"\1an-at-arms", xhtml)
 	xhtml = regex.sub(r"\b([Tt])abled’hôte", r"\1able-d’hôte", xhtml)
@@ -80,21 +78,18 @@ def modernize_hyphenation(xhtml: str) -> str:
 
 def detect_problem_spellings(xhtml: str) -> list:
 	"""
-	Return a list of potential problem spellings, that cannot be scripted due to a
-	word having various meanings.
+	Return a list of potential problem spellings, that cannot be scripted due to a word having various meanings.
 
-	For example, "staid" can be an archaic spelling of "stayed",
-	or as an adjective it could mean "marked by settled sedateness
-	and often prim self-restraint".
+	For example, `staid` can be an archaic spelling of `stayed`, or as an adjective it could mean `marked by settled sedateness and often prim self-restraint`.
 
 	INPUTS
-	xhtml: A string of XHTML to inspect
+	xhtml: A string of XHTML to inspect.
 
 	OUTPUTS
-	A list of strings representing potential words to manually inspect
+	A list of strings representing potential words to manually inspect.
 	"""
 
-	# Uncomment if we eventually need the document language
+	# Uncomment if we eventually need the document language.
 	# language = get_xhtml_language(xhtml)
 	output = []
 
@@ -132,25 +127,24 @@ def modernize_spelling(xhtml: str) -> str:
 	Convert old-timey spelling on a case-by-case basis.
 
 	INPUTS
-	xhtml: A string of XHTML to modernize
+	xhtml: A string of XHTML to modernize.
 
 	OUTPUTS
-	A string representing the XHTML with its spelling modernized
+	A string representing the XHTML with its spelling modernized.
 	"""
 
 	language = get_xhtml_language(xhtml)
 
 	# ADDING NEW WORDS TO THIS LIST:
-	# A good way to check if a word is "archaic" is to do a Google N-Gram search: https://books.google.com/ngrams/graph?case_insensitive=on&year_start=1800&year_end=2000&smoothing=3
+	# A good way to check if a word is "archaic" is to do a Google N-Gram search: <https://books.google.com/ngrams/graph?case_insensitive=on&year_start=1800&year_end=2000&smoothing=3>
 	# Remember that en-US and en-GB differ significantly, and just because a word might seem strange to you, doesn't mean it's not the common case in the other variant.
-	# If Google N-Gram shows that a word has declined significantly in usage in BOTH en-US and en-GB (or the SE editor-in-chief makes an exception) then it may be a good candidate to add to this list.
+	# If Google N-Gram shows that a word has declined significantly in usage in *both* en-US and en-GB (or the SE editor-in-chief makes an exception) then it may be a good candidate to add to this list.
 
-
-        # spelling changes on words with no diacritics or elision quotes
+        # Spelling changes on words with no diacritics or elision quotes.
 	xhtml = regex.sub(r"(?<![Cc]ompl)exion", r"ection", xhtml)			# -extion -> -exction (connexion, reflexion, etc., but "complexion")
 	xhtml = regex.sub(r"([^\p{Lowercase_Letter}]’[Tt])\s(is|were|was|wasn’t|isn’t|ain’t)\b", r"\1\2", xhtml)	# 't is, 't was, 't were 't isn't -> 'tis, 'twas, 'twere, 't isn't
 	xhtml = regex.sub(r"&amp;c\.", r"etc.", xhtml)					# &c. -> etc.
-	xhtml = regex.sub(r"\b[Aa] propos\b", r"\1propos", xhtml)			# a propos -> apropos
+	xhtml = regex.sub(r"\b([Aa]) propos\b", r"\1propos", xhtml)			# a propos -> apropos
 	xhtml = regex.sub(r"\b([Aa])fr(i|ee)te?", r"\1freet", xhtml)			# afrit -> afreet
 	xhtml = regex.sub(r"\b([Aa])larum\b", r"\1larm", xhtml)				# alarum -> alarm
 	xhtml = regex.sub(r"\b([Aa])lledg(ing|e[sd])", r"\1lleg\2", xhtml)		# alledge -> allege
@@ -385,9 +379,14 @@ def modernize_spelling(xhtml: str) -> str:
 	xhtml = regex.sub(r"\b([Tt]he|[Aa]nd|[Oo]r) what not(?! to)\b", r"\1 whatnot", xhtml)	# what not -> whatnot
 	xhtml = regex.sub(r"\b([Ww])oful", r"\1oeful", xhtml)				# woful -> woeful
 	xhtml = regex.sub(r"\b([Yy])our self\b(?!-)", r"\1ourself", xhtml)		# your self -> your self, but ignore constructs like `your self-determination` or `your selfish sister`.
+	xhtml = regex.sub(r"\b([Gg])overnour", r"\1overnor", xhtml)			# governour -> governor
+	xhtml = regex.sub(r"\b([Tt])umbler\-?full?", r"\1umblerful", xhtml)		# tumbler-full -> tumblerful
+	xhtml = regex.sub(r"\b([Ww])ine\-?glass\-?full?", r"\1ineglassful", xhtml)	# wine-glass-full -> wineglassful
+	xhtml = regex.sub(r"\b([Ss])oubriquet", r"\1obriquet", xhtml)			# soubriquet -> sobriquet
+	xhtml = regex.sub(r"\bIngulf", r"Engulf", xhtml)				# Ingulf -> Engulf
+	xhtml = regex.sub(r"\bingulf", r"engulf", xhtml)				# ingulf -> engulf
 
-
-        # remove elision quotes from words that no longer need them
+        # Remove elision quotes from words that no longer need them.
 	xhtml = regex.sub(r"’([Bb])us\b", r"\1us", xhtml)				# ’bus -> bus
 	xhtml = regex.sub(r"’([Cc])ello(s?)\b", r"\1ello\2", xhtml)			# ’cello -> cello
 	xhtml = regex.sub(r"’([Cc])ellist", r"\1ellist", xhtml)				# ’cellist -> cellist
@@ -399,7 +398,7 @@ def modernize_spelling(xhtml: str) -> str:
 	xhtml = regex.sub(r"’([Ss])cope(s?)\b", r"\1cope\2", xhtml)			# ’scope -> scope
 
 
-        # remove diacritics from words that no longer need them
+        # Remove diacritics from words that no longer need them.
 	xhtml = regex.sub(r"\b[ÀA]\s?propos\b", r"Apropos", xhtml)			# À propos -> apropos
 	xhtml = regex.sub(r"\b[àa]\s?propos\b", r"apropos", xhtml)			# à propos -> apropos
 	xhtml = regex.sub(r"\b([Aa])ërial", r"\1erial", xhtml)				# aërial -> aerial
@@ -430,7 +429,7 @@ def modernize_spelling(xhtml: str) -> str:
 	xhtml = regex.sub(r"\b([Tt])able(s?) d’hote\b", r"\1able\2 d’hôte", xhtml)	# table d'hote -> table d'hôte
 
 
-        # add diacritics to words that do need them
+        # Add diacritics to words that do need them.
 	xhtml = regex.sub(r"\ba la\b", r"à la", xhtml)					# a la -> à la
 	xhtml = regex.sub(r"\b([Aa])ttache\b", r"\1ttaché", xhtml)			# attache -> attaché
 	xhtml = regex.sub(r"\b([Bb])ete noir", r"\1ête noir", xhtml)			# bete noir -> bête noir
@@ -441,7 +440,7 @@ def modernize_spelling(xhtml: str) -> str:
 	xhtml = regex.sub(r"\b([Cc])liche([sd]?)\b", r"\1liché\2", xhtml)		# cliche -> cliché
 	xhtml = regex.sub(r"\b([Cc])onsomme", r"\1onsommé", xhtml)			# consomme -> consommé
 	xhtml = regex.sub(r"\b([Cc])oup[\- ]de[\- ]gr[aâ]ce", r"\1oup de grâce", xhtml)	# coup-de-grace -> coup-de-grâce
-	xhtml = regex.sub(r"\b([Cc])uracao", r"\1uraçao", xhtml)			# curacao -> curaçao
+	xhtml = regex.sub(r"\b([Cc])urac(ao|oa)", r"\1uraç\2", xhtml)			# curacao -> curaçao
 	xhtml = regex.sub(r"\b([Dd])istingue\b", r"\1istingué", xhtml)			# distingue -> distingué
 	xhtml = regex.sub(r"\b[EÉ]cart[eé]\b", r"Écarté", xhtml)			# Ecarte -> Écarté
 	xhtml = regex.sub(r"\b[eé]cart[eé]\b", r"écarté", xhtml)			# ecarte -> écarté
@@ -479,11 +478,11 @@ def modernize_spelling(xhtml: str) -> str:
 	xhtml = regex.sub(r"\b([Ss])enor", r"\1eñor", xhtml)				# senor -> señor (senores, senorita/s, etc.)
 	xhtml = regex.sub(r"\b([Ss])oupcon", r"\1oupçon", xhtml)			# soupcon -> soupçon
 	xhtml = regex.sub(r"\b([Ss])[uû]ret[eé]", r"\1ûreté", xhtml)			# Surete -> Sûreté
-	xhtml = regex.sub(r"([Tt])ete-a-tete", r"\1ête-à-tête", xhtml)			# tete-a-tete -> tête-à-tête
+	xhtml = regex.sub(r"([Tt])ete[ \-]a[ \-]tete", r"\1ête-à-tête", xhtml)		# tete-a-tete -> tête-à-tête
 	xhtml = regex.sub(r"([Vv])is-a-vis", r"\1is-à-vis", xhtml)			# vis-a-vis -> vis-à-vis
 
 
-	# Normalize some names
+	# Normalize some names.
 	xhtml = regex.sub(r"Barbadoes", r"Barbados", xhtml)				# Barbadoes -> Barbados
 	xhtml = regex.sub(r"\bBehring", r"Bering", xhtml)				# Behring -> Bering (i.e. the Bering Straight)
 	xhtml = regex.sub(r"Bronte\b", r"Brontë", xhtml)				# Bronte -> Brontë
@@ -545,8 +544,10 @@ def modernize_spelling(xhtml: str) -> str:
 	xhtml = regex.sub(r"\bVishnoo", r"Vishnu", xhtml)				# Vishnoo -> Vishnu
 	xhtml = regex.sub(r"[YJ]edd?o\b", r"Edo", xhtml)				# Yeddo/Jeddo -> Edo
 	xhtml = regex.sub(r"Zymbabwe", r"Zimbabwe", xhtml)				# Zymbabwe -> Zimbabwe
+	xhtml = regex.sub(r"chianti", r"Chianti", xhtml)				# chianti -> Chianti
+	xhtml = regex.sub(r"([a-z]) Zeppelin", r"\1 zeppelin", xhtml)			# Zeppelin -> zeppelin
 
-	# Remove archaic diphthongs
+	# Remove archaic diphthongs.
 	xhtml = xhtml.replace("\bæon\b", r"aeon")
 	xhtml = xhtml.replace("\bÆon\b", r"Aeon")
 	xhtml = xhtml.replace("Æneas", r"Aeneas")
@@ -565,35 +566,35 @@ def modernize_spelling(xhtml: str) -> str:
 	xhtml = regex.sub(r"\b([Pp])æan", r"\1aean", xhtml)
 	xhtml = regex.sub(r"\b([Vv])ertebræ", r"\1ertebrae", xhtml)
 
-	# Remove spaces before contractions like `n’t` e.g. `is n’t` -> `isn’t`
+	# Remove spaces before contractions like `n’t` e.g. `is n’t` -> `isn’t`.
 	xhtml = regex.sub(r" n’t\b", r"n’t", xhtml)
 
-	# Remove spaces before contractions like `it 'll`
+	# Remove spaces before contractions like `it 'll`.
 	xhtml = regex.sub(r"([\p{Letter}])\s[‘’]ll\b", r"\1’ll", xhtml)
 
-	# Remove roman ordinals
+	# Remove roman ordinals.
 	xhtml = regex.sub(r"<span epub:type=\"z3998:roman\">(.*?)</span>(st|nd|rd|th)\b", r'<span epub:type="z3998:roman">\1</span>', xhtml)
 
-	# X-ray is always capitalized. Match a preceding space so that we don't catch it in an ID attribute.
+	# `X-ray` is always capitalized. Match a preceding space so that we don't catch it in an ID attribute.
 	xhtml = regex.sub(r"([\p{Punctuation}\s])x-ray", r"\1X-ray", xhtml)
 
-	# Replace 2d with 2nd and 3d with 3rd
+	# Replace `2d` with `2nd` and `3d` with `3rd`.
 	# Check for a following abbr because `3<abbr>d.</abbr>` could mean `3 pence`
 	xhtml = regex.sub(r"\b([0-9]*2)d(?!</abbr>)", r"\1nd", xhtml)
 	xhtml = regex.sub(r"\b([0-9]*3)d(?!</abbr>)", r"\1rd", xhtml)
 
-	# Canadian spelling follows US
+	# Canadian spelling follows US.
 	if language in ["en-US", "en-CA"]:
 		xhtml = regex.sub(r"\b([Cc])osey", r"\1ozy", xhtml)
 
-	# Australian and Irish spelling follows GB
+	# Australian and Irish spelling follows GB.
 	if language in ["en-GB", "en-AU", "en-IE"]:
 		xhtml = regex.sub(r"\b([Cc])osey", r"\1osy", xhtml)
 
-	# US spelling is unique
+	# US spelling is unique.
 	if language == "en-US":
 		xhtml = regex.sub(r"\b([Mm])anœuvred", r"\1aneuvered", xhtml)
-		xhtml = regex.sub(r"\b([Mm])anœuv(?:er|re)", r"\1aneuver", xhtml) # Omit last letter to catch both maneuverS and maneuverING
+		xhtml = regex.sub(r"\b([Mm])anœuv(?:er|re)", r"\1aneuver", xhtml) # Omit last letter to catch both `maneuvers and `maneuvering`.
 		xhtml = regex.sub(r"\b([Mm])anœuvering", r"\1aneuvering", xhtml)
 	else:
 		xhtml = regex.sub(r"\b([Mm])anœuvred", r"\1anoeuvred", xhtml)
